==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF05S.sql <==
/****************************************************************************/
/* GF05 ( ﾃｰﾌﾞﾙｶﾗﾑ定義 )                                                    */
/*                                                                          */
/* Created : 2015/11/16 16:20:15                                            */
/****************************************************************************/
CREATE TABLE GF05 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (    1 )                  NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          varchar           (   30 )                  NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      varchar           (  200 )                                      /*  60 名称         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   varchar           (    9 )      DEFAULT 0                       /*  80 使用桁数     */
 , DATA_DEFAULT varchar           (  200 )                                      /*  90 初期値       */
 , NOT_NULL     varchar           (    1 )                                      /* 100 ﾉｯﾄﾇﾙ        */
 , FGCOM        varchar           (    1 )      DEFAULT 0   NOT NULL            /* 110 共通項目F    */
 , RENDERER     varchar           (   10 )                                      /* 120 表示種別     */
 , EDITOR       varchar           (   10 )                                      /* 130 編集種別     */
 , DBTYPE       varchar           (   10 )                                      /* 140 文字種別     */
 , BIKO         varchar           ( 2000 )                                      /* 150 備考         */
 , CDKH         varchar           (    1 )                                      /* 160 改廃ｺｰﾄﾞ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion6.4.2.0_dev.zip: uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF05S.sql <==
/****************************************************************************/
/* GF05 ( ﾃｰﾌﾞﾙｶﾗﾑ定義 )                                                    */
/*                                                                          */
/* Created : 2016/01/07 17:07:27                                            */
/****************************************************************************/
CREATE TABLE GF05 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (    1 )                  NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , CLM          varchar           (   30 )                  NOT NULL            /*  40 項目         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  50 表示順       */
 , NAME_JA      varchar           (  200 )                                      /*  60 名称         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  70 DBｸﾗｽ        */
 , USE_LENGTH   varchar           (    9 )      DEFAULT 0                       /*  80 使用桁数     */
 , DATA_DEFAULT varchar           (  200 )                                      /*  90 初期値       */
 , NOT_NULL     varchar           (    1 )                                      /* 100 ﾉｯﾄﾇﾙ        */
 , KBCLM        varchar           (    1 )      DEFAULT 0   NOT NULL            /* 120 ｶﾗﾑ区分      */
 , RENDERER     varchar           (   10 )                                      /* 130 表示種別     */
 , EDITOR       varchar           (   10 )                                      /* 140 編集種別     */
 , DBTYPE       varchar           (   10 )                                      /* 150 文字種別     */
 , BIKO         varchar           ( 2000 )                                      /* 160 備考         */
 , CDKH         varchar           (    1 )                                      /* 170 改廃ｺｰﾄﾞ     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
